@@ -22,10 +22,11 @@
     Py_buffer VEC_view; \
     int VEC_err = PyObject_GetBuffer(VEC_obj, &VEC_view, PyBUF_WRITABLE|PyBUF_FORMAT); \
     if (VEC_err < 0 || sizeof(*VEC_buf) != VEC_view.itemsize) return NULL; \
-    VEC_buf = (typeof(VEC_buf))VEC_view.buf; \
+    VEC_buf = VEC_view.buf; \
     VEC_len = VEC_view.len/sizeof(*VEC_buf); \
     PyBuffer_Release(&VEC_view); \
   } while (0)
+  // Maybe use:   VEC_buf = (typeof(VEC_buf))VEC_view.buf;
 #else
   #define VECTOR(VEC_obj, VEC_buf, VEC_len) do { \
     int VEC_err = PyObject_AsWriteBuffer(VEC_obj, (void **)(&VEC_buf), &VEC_len); \
