@@ -107,7 +107,6 @@ class DialogAbout(wx.Dialog):
         self.bitmap_button_ansto = wx.BitmapButton(self, -1, wx.NullBitmap)
         self.bitmap_button_tudelft = wx.BitmapButton(self, -1, wx.NullBitmap)
         self.bitmap_button_dls = wx.BitmapButton(self, -1, wx.NullBitmap)
-        self.bitmap_button_bam = wx.BitmapButton(self, -1, wx.NullBitmap)
 
         self.static_line_3 = wx.StaticLine(self, -1)
         self.button_OK = wx.Button(self, wx.ID_OK, "OK")
@@ -128,7 +127,6 @@ class DialogAbout(wx.Dialog):
         self.Bind(wx.EVT_BUTTON, self.onAnstoLogo, self.bitmap_button_ansto)
         self.Bind(wx.EVT_BUTTON, self.onTudelftLogo, self.bitmap_button_tudelft)
         self.Bind(wx.EVT_BUTTON, self.onDlsLogo, self.bitmap_button_dls)
-        self.Bind(wx.EVT_BUTTON, self.onBamLogo, self.bitmap_button_bam)
         # end wxGlade
         # fill in acknowledgements
         #self.text_ctrl_acknowledgement.SetValue(__acknowledgement__)
@@ -228,12 +226,6 @@ class DialogAbout(wx.Dialog):
         logo = wx.Bitmap(image)
         self.bitmap_button_dls.SetBitmapLabel(logo)
 
-        image = file_dir + "/images/bam_logo.png"
-        if os.path.isfile(config._bam_logo):
-            image = config._bam_logo
-        logo = wx.Bitmap(image)
-        self.bitmap_button_bam.SetBitmapLabel(logo)
-
         # resize dialog window to fit version number nicely
         if wx.VERSION >= (2, 7, 2, 0):
             size = [self.GetEffectiveMinSize()[0], self.GetSize()[1]]
@@ -265,7 +257,6 @@ class DialogAbout(wx.Dialog):
         self.bitmap_button_ansto.SetSize(self.bitmap_button_ansto.GetBestSize())
         self.bitmap_button_tudelft.SetSize(self.bitmap_button_tudelft.GetBestSize())
         self.bitmap_button_dls.SetSize(self.bitmap_button_dls.GetBestSize())
-        self.bitmap_button_bam.SetSize(self.bitmap_button_bam.GetBestSize())
         # end wxGlade
 
     def __do_layout(self):
@@ -333,8 +324,6 @@ class DialogAbout(wx.Dialog):
                         wx.LEFT|wx.ADJUST_MINSIZE, 2)
         sizer_logos.Add(self.bitmap_button_dls, 0,
                         wx.LEFT|wx.ADJUST_MINSIZE, 2)
-        sizer_logos.Add(self.bitmap_button_bam, 0,
-                        wx.LEFT|wx.ADJUST_MINSIZE, 2)
 
         sizer_logos.Add((10, 50), 0, wx.ADJUST_MINSIZE, 0)
         sizer_main.Add(sizer_logos, 0, wx.EXPAND, 0)
@@ -440,13 +429,6 @@ class DialogAbout(wx.Dialog):
         launchBrowser(config._dls_url)
         event.Skip()
 
-    def onBamLogo(self, event):
-        """
-        """
-        # wxGlade: DialogAbout.<event_handler>
-        launchBrowser(config._bam_url)
-        event.Skip()
-
 # end of class DialogAbout
 
 ##### testing code ############################################################
