@@ -757,7 +757,7 @@ class GridPage(sheet.CSheet):
         THIS METHOD IS NOT CURRENTLY USED.  It is designed to provide a
         cell pop up context by right clicking on a cell and gives the
         option to cut, paste, and clear. This will probably be removed in
-        future versions and is being superseded by more traditional cut and
+        future versions and is being superceded by more traditional cut and
         paste options.
         """
 
@@ -799,7 +799,7 @@ class GridPage(sheet.CSheet):
 
         THIS METHOD IS NOT CURRENTLY USED.  it is part of right click cell
         context menu which is being removed. This will probably be removed in
-        future versions and is being superseded by more traditional cut and
+        future versions and is being superceded by more traditional cut and
         paste options
         """
 
@@ -811,7 +811,7 @@ class GridPage(sheet.CSheet):
 
         THIS METHOD IS NOT CURRENTLY USED.  it is part of right click cell
         context menu which is being removed. This will probably be removed in
-        future versions and is being superseded by more traditional cut and
+        future versions and is being superceded by more traditional cut and
         paste options
         """
 
@@ -827,7 +827,7 @@ class GridPage(sheet.CSheet):
 
         THIS METHOD IS NOT CURRENTLY USED.  it is part of right click cell
         context menu which is being removed. This will probably be removed in
-        future versions and is being superseded by more traditional cut and
+        future versions and is being superceded by more traditional cut and
         paste options
         """
 
@@ -908,20 +908,20 @@ class Notebook(nb, PanelBase):
                 if c != col:
                     msg = "Edit axis doesn't understand this selection.\n"
                     msg += "Please select only one column"
-                    raise ValueError, msg
+                    raise (ValueError, msg)
             for (_, cell_col) in grid.selected_cells:
                 if cell_col != col:
                     msg = "Cannot use cells from different columns for "
                     msg += "this operation.\n"
                     msg += "Please select elements of the same col.\n"
-                    raise ValueError, msg
+                    raise (ValueError, msg)
 
             # Finally check the highlighted cell if any cells missing
             self.get_highlighted_row(True)
         else:
             msg = "No item selected.\n"
             msg += "Please select only one column or one cell"
-            raise ValueError, msg
+            raise (ValueError, msg)
         return grid.selected_cells
 
     def get_highlighted_row(self, is_number=True):
@@ -1232,7 +1232,7 @@ class GridPanel(SPanel):
     def on_view(self, event):
         """
         Get object represented by the given cells and plot them.  Basically
-        plot the column in y vs the column in x.
+        plot the colum in y vs the column in x.
         """
 
         pos = self.notebook.GetSelection()
@@ -1325,7 +1325,7 @@ class GridPanel(SPanel):
         try:
             if sentence.strip() == "":
                 msg = "Select column values for x axis"
-                raise ValueError, msg
+                raise (ValueError, msg)
         except:
             msg = "X axis value error."
             wx.PostEvent(self.parent.parent, StatusEvent(status=msg, info="error"))
@@ -1344,7 +1344,7 @@ class GridPanel(SPanel):
         try:
             if sentence.strip() == "":
                 msg = "select value for y axis"
-                raise ValueError, msg
+                raise (ValueError, msg)
         except:
             msg = "Y axis value error."
             wx.PostEvent(self.parent.parent, StatusEvent(status=msg, info="error"))
@@ -1630,7 +1630,7 @@ class GridFrame(wx.Frame):
         wx.EVT_MENU(self, self.save_menu.GetId(), self.on_save_page)
 
         # We need to grab a WxMenu handle here, otherwise the next one to grab
-        # the handle will be treated as the Edit Menu handle when checking in
+        # the handle will be treated as the Edi)t Menu handle when checking in
         # on_menu_open event handler and thus raise an exception when it hits an 
         # unitialized object.  Alternative is to comment out that whole section
         # in on_menu_open, but that would make it more difficult to undo the
@@ -1960,7 +1960,7 @@ class BatchOutputFrame(wx.Frame):
         iy += 1
         selection_sizer.Add(self.save_to_file, (iy, ix),
                             (1, 1), wx.LEFT | wx.EXPAND | wx.ADJUST_MINSIZE, 15)
-        #contruction the sizer containing button
+        #contruction the sizer contaning button
         button_sizer.Add((20, 20), 1, wx.EXPAND | wx.ADJUST_MINSIZE, 0)
 
         button_sizer.Add(button_close, 0,
