@@ -22,7 +22,7 @@ the names of the first and second model and the operator to be used).
 #
 #copyright 2009, University of Tennessee
 ################################################################################
-from __future__ import print_function
+
 
 import wx
 import sys
@@ -42,11 +42,11 @@ logger = logging.getLogger(__name__)
 
 if sys.platform.count("win32") > 0:
     FONT_VARIANT = 0
-    PNL_WIDTH = 500
+    PNL_WIDTH = 450
     PNL_HEIGHT = 320
 else:
     FONT_VARIANT = 1
-    PNL_WIDTH = 500
+    PNL_WIDTH = 590
     PNL_HEIGHT = 350
 M_NAME = 'Model'
 EDITOR_WIDTH = 800
@@ -337,13 +337,13 @@ class TextDialog(wx.Dialog):
             #Create list of existing model names for comparison
             list_fnames = os.listdir(self.plugin_dir)
             # fake existing regular model name list
-            m_list = [model + ".py" for model in self.model_list]
+            m_list = [model.name + ".py" for model in self.model_list]
             list_fnames.append(m_list)
             if t_fname in list_fnames and title != mname:
                 self.good_name = False
                 msg = "Name exists already."
 
-        if not self.good_name:
+        if self.good_name == False:
             self.name_tcl.SetBackgroundColour('pink')
             info = 'Error'
             wx.MessageBox(msg, info)
@@ -390,7 +390,6 @@ class TextDialog(wx.Dialog):
             color = 'red'
         self._msg_box.SetLabel(msg)
         self._msg_box.SetForegroundColour(color)
-        self._set_model_list()
         if self.parent.parent is not None:
             from sas.sasgui.guiframe.events import StatusEvent
             wx.PostEvent(self.parent.parent, StatusEvent(status=msg,
@@ -432,8 +431,6 @@ class TextDialog(wx.Dialog):
 
         if len(main_list) > 1:
             main_list.sort()
-        self.model1.Clear()
-        self.model2.Clear()
         for idx in range(len(main_list)):
             self.model1.Append(str(main_list[idx]), idx)
             self.model2.Append(str(main_list[idx]), idx)
@@ -494,25 +491,18 @@ class TextDialog(wx.Dialog):
         """
         Choose the equation to use depending on whether we now have
         a sum or multiply model then create the appropriate string
-        
-        for the sum model the result will be:
-        scale_factor * (scale1 * model_1 + scale2 * model_2) + background
-        while for the multiply model it will just be:
-        scale_factor * (model_1* model_2) + background
         """
         name = ''
         if operator == '*':
             name = 'Multi'
-            factor_1 = ''
-            factor_2 = ''
+            factor = 'background'
         else:
             name = 'Sum'
-            factor_1 = 'scale_1 * '
-            factor_2 = 'scale_2 * '
+            factor = 'scale_factor'
 
         self._operator = operator
-        self.explanation = ("  Plugin_model = scale_factor * ({}model_1 {} "
-            "{}model_2) + background").format(factor_1,operator,factor_2)
+        self.explanation = ("  Plugin_model = scale_factor * (model_1 {} "
+            "model_2) + background").format(operator)
         self.explanationctr.SetLabel(self.explanation)
         self.name = name + M_NAME
 
@@ -669,9 +659,11 @@ class EditorPanel(wx.ScrolledWindow):
         """
         Do the layout for parameter related widgets
         """
-        param_txt = wx.StaticText(self, -1, 'Fit Parameters: ')
+        param_txt = wx.StaticText(self, -1, 'Fit Parameters NOT requiring' + \
+                                  ' polydispersity (if any): ')
 
-        param_tip = "#Set the parameters and their initial values.\n"
+        param_tip = "#Set the parameters NOT requiring polydispersity " + \
+        "and their initial values.\n"
         param_tip += "#Example:\n"
         param_tip += "A = 1\nB = 1"
         #param_txt.SetToolTipString(param_tip)
@@ -685,6 +677,23 @@ class EditorPanel(wx.ScrolledWindow):
         self.param_sizer.AddMany([(param_txt, 0, wx.LEFT, 10),
                                   (self.param_tcl, 1, wx.EXPAND | wx.ALL, 10)])
 
+        # Parameters with polydispersity
+        pd_param_txt = wx.StaticText(self, -1, 'Fit Parameters requiring ' + \
+                                     'polydispersity (if any): ')
+
+        pd_param_tip = "#Set the parameters requiring polydispersity and " + \
+        "their initial values.\n"
+        pd_param_tip += "#Example:\n"
+        pd_param_tip += "C = 2\nD = 2"
+        newid = wx.NewId()
+        self.pd_param_tcl = EditWindow(self, newid, wx.DefaultPosition,
+                                    wx.DefaultSize,
+                                    wx.CLIP_CHILDREN | wx.SUNKEN_BORDER)
+        self.pd_param_tcl.setDisplayLineNumbers(True)
+        self.pd_param_tcl.SetToolTipString(pd_param_tip)
+
+        self.param_sizer.AddMany([(pd_param_txt, 0, wx.LEFT, 10),
+                                  (self.pd_param_tcl, 1, wx.EXPAND | wx.ALL, 10)])
 
     def _layout_function(self):
         """
@@ -780,7 +789,7 @@ class EditorPanel(wx.ScrolledWindow):
         for item in dir(math):
             if item.count("_") < 1:
                 try:
-                    exec "float(math.%s)" % item
+                    exec("float(math.%s)" % item)
                     self.math_combo.Append(str(item))
                 except Exception:
                     self.math_combo.Append(str(item) + "()")
@@ -886,12 +895,13 @@ class EditorPanel(wx.ScrolledWindow):
         elif self.check_name():
             description = self.desc_tcl.GetValue()
             param_str = self.param_tcl.GetText()
+            pd_param_str = self.pd_param_tcl.GetText()
             func_str = self.function_tcl.GetText()
             # No input for the model function
             if func_str.lstrip().rstrip():
                 if func_str.count('return') > 0:
                     self.write_file(self.fname, name, description, param_str,
-                                    func_str)
+                                    pd_param_str, func_str)
                     try:
                         result, msg = check_model(self.fname), None
                     except Exception:
@@ -931,13 +941,14 @@ class EditorPanel(wx.ScrolledWindow):
                          StatusEvent(status=msg+check_err, info=info))
         self.warning = msg
 
-    def write_file(self, fname, name, desc_str, param_str, func_str):
+    def write_file(self, fname, name, desc_str, param_str, pd_param_str, func_str):
         """
         Write content in file
 
         :param fname: full file path
         :param desc_str: content of the description strings
         :param param_str: content of params; Strings
+        :param pd_param_str: content of params requiring polydispersity; Strings
         :param func_str: content of func; Strings
         """
         out_f = open(fname, 'w')
@@ -951,29 +962,39 @@ class EditorPanel(wx.ScrolledWindow):
 
         # Write out parameters
         param_names = []    # to store parameter names
+        pd_params = []
         out_f.write('parameters = [ \n')
         out_f.write('#   ["name", "units", default, [lower, upper], "type", "description"],\n')
         for pname, pvalue, desc in self.get_param_helper(param_str):
             param_names.append(pname)
             out_f.write("    ['%s', '', %s, [-inf, inf], '', '%s'],\n"
                         % (pname, pvalue, desc))
+        for pname, pvalue, desc in self.get_param_helper(pd_param_str):
+            param_names.append(pname)
+            pd_params.append(pname)
+            out_f.write("    ['%s', '', %s, [-inf, inf], 'volume', '%s'],\n"
+                        % (pname, pvalue, desc))
         out_f.write('    ]\n')
 
         # Write out function definition
-        out_f.write('\n')
         out_f.write('def Iq(%s):\n' % ', '.join(['x'] + param_names))
         out_f.write('    """Absolute scattering"""\n')
         if "scipy." in func_str:
-            out_f.write('    import scipy\n')
+            out_f.write('    import scipy')
         if "numpy." in func_str:
-            out_f.write('    import numpy\n')
+            out_f.write('    import numpy')
         if "np." in func_str:
-            out_f.write('    import numpy as np\n')
+            out_f.write('    import numpy as np')
         for func_line in func_str.split('\n'):
-            out_f.write('%s%s\n' % ('    ', func_line))
+            out_f.write('%s%s\n' % (spaces4, func_line))
         out_f.write('## uncomment the following if Iq works for vector x\n')
         out_f.write('#Iq.vectorized = True\n')
 
+        # If polydisperse, create place holders for form_volume, ER and VR
+        if pd_params:
+            out_f.write('\n')
+            out_f.write(CUSTOM_TEMPLATE_PD % {'args': ', '.join(pd_params)})
+
         # Create place holder for Iqxy
         out_f.write('\n')
         out_f.write('#def Iqxy(%s):\n' % ', '.join(["x", "y"] + param_names))
@@ -1105,6 +1126,31 @@ description = """%(description)s"""
 
 '''
 
+CUSTOM_TEMPLATE_PD = '''\
+def form_volume(%(args)s):
+    """
+    Volume of the particles used to compute absolute scattering intensity
+    and to weight polydisperse parameter contributions.
+    """
+    return 0.0
+
+def ER(%(args)s):
+    """
+    Effective radius of particles to be used when computing structure factors.
+
+    Input parameters are vectors ranging over the mesh of polydispersity values.
+    """
+    return 0.0
+
+def VR(%(args)s):
+    """
+    Volume ratio of particles to be used when computing structure factors.
+
+    Input parameters are vectors ranging over the mesh of polydispersity values.
+    """
+    return 1.0
+'''
+
 SUM_TEMPLATE = """
 from sasmodels.core import load_model_info
 from sasmodels.sasview_model import make_model_from_info
