@@ -11,7 +11,6 @@ import sas.sascalc.dataloader
 # from xml.dom.minidom import parse
 from lxml import etree
 from sas.sascalc.dataloader.readers.cansas_reader import Reader as CansasReader
-from sas.sasgui.guiframe.report_image_handler import ReportImageHandler
 from sas.sascalc.dataloader.readers.cansas_reader import get_content
 from sas.sasgui.guiframe.utils import format_number
 from sas.sasgui.guiframe.gui_style import GUIFRAME_ID
@@ -129,17 +128,15 @@ class InvariantState(object):
         compute_state = self.state_list[str(compute_num)]
         my_time, date = self.timestamp
         file_name = self.file
-        from sas.sasview.__init__ import __version__ as sasview_version
 
         state_num = int(self.saved_state['state_num'])
         state = "\n[Invariant computation for %s: " % file_name
-        state += "performed at %s on %s] " % (my_time, date)
-        state += "[SasView v%s]\n" % (sasview_version)
+        state += "performed at %s on %s] \n" % (my_time, date)
         state += "State No.: %d \n" % state_num
         state += "\n=== Inputs ===\n"
 
         # text ctl general inputs ( excluding extrapolation text ctl)
-        for key, value in self.input_list.iteritems():
+        for key, value in self.input_list.items():
             if value == '':
                 continue
             key_split = key.split('_')
@@ -165,7 +162,7 @@ class InvariantState(object):
         state += "\nExtrapolation:  High=%s; Low=%s\n" % (extra_hi, extra_lo)
         low_off = False
         high_off = False
-        for key, value in self.input_list.iteritems():
+        for key, value in self.input_list.items():
             key_split = key.split('_')
             max_ind = len(key_split) - 1
             if key_split[max_ind] == 'tcl':
@@ -215,7 +212,7 @@ class InvariantState(object):
             else:
                 # other outputs than Q*
                 name = item[0] + "_tcl"
-                if name in self.saved_state.keys():
+                if name in list(self.saved_state.keys()):
                     value = self.saved_state[name]
 
             # Exclude the outputs w/''
@@ -300,7 +297,7 @@ class InvariantState(object):
         state = newdoc.createElement("state")
         top_element.appendChild(state)
 
-        for name, value in self.saved_state.iteritems():
+        for name, value in self.saved_state.items():
             element = newdoc.createElement(str(name))
             element.appendChild(newdoc.createTextNode(str(value)))
             state.appendChild(element)
@@ -309,9 +306,9 @@ class InvariantState(object):
         history = newdoc.createElement("history")
         top_element.appendChild(history)
 
-        for name, value in self.state_list.iteritems():
+        for name, value in self.state_list.items():
             history_element = newdoc.createElement('state_' + str(name))
-            for state_name, state_value in value.iteritems():
+            for state_name, state_value in value.items():
                 state_element = newdoc.createElement(str(state_name))
                 child = newdoc.createTextNode(str(state_value))
                 state_element.appendChild(child)
@@ -324,7 +321,7 @@ class InvariantState(object):
         bookmark = newdoc.createElement("bookmark")
         top_element.appendChild(bookmark)
         item_list = ['time', 'date', 'state', 'comp_state']
-        for name, value_list in self.bookmark_list.iteritems():
+        for name, value_list in self.bookmark_list.items():
             element = newdoc.createElement('mark_' + str(name))
             _, date, state, comp_state = value_list
             time_element = newdoc.createElement('time')
@@ -333,12 +330,12 @@ class InvariantState(object):
             date_element.appendChild(newdoc.createTextNode(str(value_list[1])))
             state_list_element = newdoc.createElement('state')
             comp_state_list_element = newdoc.createElement('comp_state')
-            for state_name, state_value in value_list[2].iteritems():
+            for state_name, state_value in value_list[2].items():
                 state_element = newdoc.createElement(str(state_name))
                 child = newdoc.createTextNode(str(state_value))
                 state_element.appendChild(child)
                 state_list_element.appendChild(state_element)
-            for comp_name, comp_value in value_list[3].iteritems():
+            for comp_name, comp_value in value_list[3].items():
                 comp_element = newdoc.createElement(str(comp_name))
                 comp_element.appendChild(newdoc.createTextNode(str(comp_value)))
                 comp_state_list_element.appendChild(comp_element)
@@ -367,7 +364,7 @@ class InvariantState(object):
         if file is not None:
             msg = "InvariantSate no longer supports non-CanSAS"
             msg += " format for invariant files"
-            raise RuntimeError, msg
+            raise RuntimeError(msg)
 
         if node.get('version')\
             and node.get('version') == '1.0':
@@ -384,7 +381,7 @@ class InvariantState(object):
                     timestamp = (entry.get('epoch'))
                 except:
                     msg = "InvariantSate.fromXML: Could not read"
-                    msg += " timestamp\n %s" % sys.exc_value
+                    msg += " timestamp\n %s" % sys.exc_info()[1]
                     logger.error(msg)
 
             # Parse bookmarks
@@ -456,7 +453,7 @@ class InvariantState(object):
 
         # default string values
         for num in range(1, 19):
-            exec "s_%s = 'NA'" % str(num)
+            exec("s_%s = 'NA'" % str(num))
         lines = strings.split('\n')
         # get all string values from __str__()
         for line in range(0, len(lines)):
@@ -613,10 +610,14 @@ class InvariantState(object):
         # get the dynamic image for the htmlwindow
         wximgbmp = wx.BitmapFromImage(wximg)
         # store the image in wx.FileSystem Object
-        imgs, refs = ReportImageHandler.set_figs([fig], [wximgbmp], 'inv')
+        wx.FileSystem.AddHandler(wx.MemoryFSHandler())
+        # use wx.MemoryFSHandler
+        self.imgRAM = wx.MemoryFSHandler()
+        # AddFile, image can be retrieved with 'memory:filename'
+        self.imgRAM.AddFile('img_inv.png', wximgbmp, wx.BITMAP_TYPE_PNG)
 
-        self.wximgbmp = refs[0]
-        self.image = imgs[0]
+        self.wximgbmp = 'memory:img_inv.png'
+        self.image = fig
 
 class Reader(CansasReader):
     """
@@ -653,7 +654,7 @@ class Reader(CansasReader):
         : param path: file path
         : return: None
         """
-        if self.cansas:
+        if self.cansas == True:
             return self._read_cansas(path)
         else:
             return self._read_standalone(path)
@@ -693,7 +694,7 @@ class Reader(CansasReader):
                 state.fromXML(node=nodes[0])
         except:
             msg = "XML document does not contain invariant"
-            msg += " information.\n %s" % sys.exc_value
+            msg += " information.\n %s" % sys.exc_info()[1]
             logger.info(msg)
         return state
 
@@ -735,7 +736,7 @@ class Reader(CansasReader):
                         sas_entry.filename = invstate.file
                         output.append(sas_entry)
         else:
-            raise RuntimeError, "%s is not a file" % path
+            raise RuntimeError("%s is not a file" % path)
 
         # Return output consistent with the loader's api
         if len(output) == 0:
@@ -761,7 +762,7 @@ class Reader(CansasReader):
         : param invstate: InvariantState object
         """
         # Sanity check
-        if self.cansas:
+        if self.cansas == True:
             doc = self.write_toXML(datainfo, invstate)
             # Write the XML document
             fd = open(filename, 'w')
@@ -781,7 +782,7 @@ class Reader(CansasReader):
         elif not issubclass(datainfo.__class__, sas.sascalc.dataloader.data_info.Data1D):
             msg = "The cansas writer expects a Data1D"
             msg += " instance: %s" % str(datainfo.__class__.__name__)
-            raise RuntimeError, msg
+            raise RuntimeError(msg)
         # make sure title and data run is filled up.
         if datainfo.title is None or datainfo.title == '':
             datainfo.title = datainfo.name
