@@ -237,7 +237,7 @@ class InversionState(object):
         if file is not None:
             msg = "InversionState no longer supports non-CanSAS"
             msg += " format for P(r) files"
-            raise RuntimeError, msg
+            raise RuntimeError(msg)
 
         if node.get('version') and node.get('version') == '1.0':
 
@@ -253,7 +253,7 @@ class InversionState(object):
                     self.timestamp = float(entry.get('epoch'))
                 except:
                     msg = "InversionState.fromXML: Could not read "
-                    msg += "timestamp\n %s" % sys.exc_value
+                    msg += "timestamp\n %s" % sys.exc_info()[1]
                     logger.error(msg)
 
             # Parse inversion inputs
@@ -388,7 +388,7 @@ class Reader(CansasReader):
         :return: None
 
         """
-        if self.cansas:
+        if self.cansas == True:
             return self._read_cansas(path)
         else:
             return self._read_standalone(path)
@@ -433,7 +433,7 @@ class Reader(CansasReader):
                 state.fromXML(node=nodes[0])
         except:
             msg = "XML document does not contain P(r) "
-            msg += "information.\n %s" % sys.exc_value
+            msg += "information.\n %s" % sys.exc_info()[1]
             logger.info(msg)
 
         return state
@@ -480,7 +480,7 @@ class Reader(CansasReader):
                         sas_entry.filename = prstate.file
                         output.append(sas_entry)
         else:
-            raise RuntimeError, "%s is not a file" % path
+            raise RuntimeError("%s is not a file" % path)
 
         # Return output consistent with the loader's api
         if len(output) == 0:
@@ -504,7 +504,7 @@ class Reader(CansasReader):
 
         """
         # Sanity check
-        if self.cansas:
+        if self.cansas == True:
             doc = self.write_toXML(datainfo, prstate)
             # Write the XML document
             fd = open(filename, 'w')
@@ -524,7 +524,7 @@ class Reader(CansasReader):
         elif not issubclass(datainfo.__class__, Data1D):
             msg = "The cansas writer expects a Data1D "
             msg += "instance: %s" % str(datainfo.__class__.__name__)
-            raise RuntimeError, msg
+            raise RuntimeError(msg)
 
         # Create basic XML document
         doc, sasentry = self._to_xml_doc(datainfo)
