@@ -1,7 +1,7 @@
 """
     Plot panel.
 """
-from __future__ import print_function
+
 
 import logging
 import traceback
@@ -15,15 +15,15 @@ matplotlib.use('WXAgg')
 from matplotlib.backends.backend_wxagg import FigureCanvasWxAgg
 from matplotlib.figure import Figure
 import os
-import transform
+from . import transform
 #TODO: make the plottables interactive
-from binder import BindArtist
+from .binder import BindArtist
 from matplotlib.font_manager import FontProperties
 DEBUG = False
 
-from plottables import Graph
-from TextDialog import TextDialog
-from LabelDialog import LabelDialog
+from .plottables import Graph
+from .TextDialog import TextDialog
+from .LabelDialog import LabelDialog
 import operator
 
 import math
@@ -43,7 +43,7 @@ def show_tree(obj, d=0):
     if 'get_children' in dir(obj):
         for a in obj.get_children(): show_tree(a, d + 1)
 
-from convert_units import convert_unit
+from .convert_units import convert_unit
 
 
 def _rescale(lo, hi, step, pt=None, bal=None, scale='linear'):
@@ -115,7 +115,7 @@ class PlotPanel(wx.Panel):
         self.line_collections_list = []
         self.figure = Figure(None, dpi, linewidth=2.0)
         self.color = '#b3b3b3'
-        from canvas import FigureCanvas
+        from .canvas import FigureCanvas
         self.canvas = FigureCanvas(self, -1, self.figure)
         self.SetColor(color)
         self._resizeflag = True
@@ -475,7 +475,7 @@ class PlotPanel(wx.Panel):
             #Disable dragging without the toolbar to allow zooming with toolbar
             return
         self.mousemotion = True
-        if self.leftdown and self.mousemotion:
+        if self.leftdown == True and self.mousemotion == True:
             ax = event.inaxes
             if ax is not None:  # the dragging is perform inside the figure
                 self.xFinal, self.yFinal = event.xdata, event.ydata
@@ -656,10 +656,10 @@ class PlotPanel(wx.Panel):
                     plot_dict[item] = plotlist[item]
         else:
             plot_dict = plotlist
-        from fitDialog import LinearFit
+        from .fitDialog import LinearFit
 
-        if len(plot_dict.keys()) > 0:
-            first_item = plot_dict.keys()[0]
+        if len(list(plot_dict.keys())) > 0:
+            first_item = list(plot_dict.keys())[0]
             dlg = LinearFit(parent=None, plottable=first_item,
                             push_data=self.onFitDisplay,
                             transform=self.returnTrans,
@@ -690,7 +690,7 @@ class PlotPanel(wx.Panel):
         if len(self.plots) < 1:
             return
         name = menu.GetHelpString(id)
-        for plot in self.plots.values():
+        for plot in list(self.plots.values()):
             if plot.name == name:
                 self.graph.selected_plottable = plot.id
                 break
@@ -702,7 +702,7 @@ class PlotPanel(wx.Panel):
             :param plot: PlotPanel owning the graph
 
         """
-        from fitDialog import LinearFit
+        from .fitDialog import LinearFit
         if self._fit_dialog is not None:
             return
         self._fit_dialog = LinearFit(None, plot, self.onFitDisplay,
@@ -732,10 +732,10 @@ class PlotPanel(wx.Panel):
             self._fit_dialog.Destroy()
             self._fit_dialog = None
         plot_list = self.graph.returnPlottable()
-        if len(plot_list.keys()) > 0:
-            first_item = plot_list.keys()[0]
+        if len(list(plot_list.keys())) > 0:
+            first_item = list(plot_list.keys())[0]
             if first_item.x != []:
-                from PropertyDialog import Properties
+                from .PropertyDialog import Properties
                 dial = Properties(self, -1, 'Properties')
                 dial.setValues(self.prevXtrans, self.prevYtrans, self.viewModel)
                 if dial.ShowModal() == wx.ID_OK:
@@ -955,7 +955,7 @@ class PlotPanel(wx.Panel):
             handles, labels = self.subplot.get_legend_handles_labels()
             hl = sorted(zip(handles, labels),
                         key=operator.itemgetter(1))
-            handles2, labels2 = zip(*hl)
+            handles2, labels2 = list(zip(*hl))
             self.line_collections_list = handles2
             self.legend = self.subplot.legend(handles2, labels2,
                                               prop=FontProperties(size=10),
@@ -985,7 +985,7 @@ class PlotPanel(wx.Panel):
         handles, labels = self.subplot.get_legend_handles_labels()
         hl = sorted(zip(handles, labels),
                     key=operator.itemgetter(1))
-        handles2, labels2 = zip(*hl)
+        handles2, labels2 = list(zip(*hl))
         self.line_collections_list = handles2
         self.legend = self.subplot.legend(handles2, labels2,
                                           prop=FontProperties(size=10),
@@ -1246,7 +1246,7 @@ class PlotPanel(wx.Panel):
                 # sort them by labels
                 hl = sorted(zip(handles, labels),
                             key=operator.itemgetter(1))
-                handles2, labels2 = zip(*hl)
+                handles2, labels2 = list(zip(*hl))
                 self.line_collections_list = handles2
                 self.legend = ax.legend(handles2, labels2,
                                         prop=FontProperties(size=10),
@@ -1326,7 +1326,7 @@ class PlotPanel(wx.Panel):
         self.subplot.set_xscale('linear')
         if id is None:
             id = name
-        from plottable_interactor import PointInteractor
+        from .plottable_interactor import PointInteractor
         p = PointInteractor(self, self.subplot, zorder=zorder, id=id)
         if p.markersize is not None:
             markersize = p.markersize
@@ -1343,7 +1343,7 @@ class PlotPanel(wx.Panel):
         self.subplot.set_xscale('linear')
         if id is None:
             id = name
-        from plottable_interactor import PointInteractor
+        from .plottable_interactor import PointInteractor
         p = PointInteractor(self, self.subplot, zorder=zorder, id=id)
         p.curve(x, y, dy=dy, color=color, symbol=symbol, zorder=zorder,
                 label=label)
@@ -1753,7 +1753,7 @@ class PlotPanel(wx.Panel):
         if remove_fit:
             self.graph.delete(self.fit_result)
             if hasattr(self, 'plots'):
-                if 'fit' in self.plots.keys():
+                if 'fit' in list(self.plots.keys()):
                     del self.plots['fit']
         self.ly = None
         self.q_ctrl = None
