@@ -1,6 +1,6 @@
 from distutils.version import StrictVersion
-__version__ = "4.2.1"
+__version__ = "5.0"
 StrictVersion(__version__)
-__DOI__ = "Zenodo, 10.5281/zenodo.2561236"
+__DOI__ = "Zenodo, DOI:10.5281/zenodo.3011184"
 __release_date__ = "2019"
-__build__ = "GIT_COMMIT"
+__build__ = "GIT_COMMIT"
\ No newline at end of file
