@@ -1,22 +1,19 @@
 """
-Application settings
+    Application settings
 """
 from __future__ import print_function
 
 import time
 import os
-import logging
-
-from sas.sasgui.guiframe.gui_style import GUIFRAME
+#from sas.sasgui.guiframe.gui_style import GUIFRAME
 import sas.sasview
+import logging
 
 logger = logging.getLogger(__name__)
 
 # Version of the application
 __appname__ = "SasView"
 __version__ = sas.sasview.__version__
-__DOI__ = sas.sasview.__DOI__
-__release_date__ = sas.sasview.__release_date__
 __build__ = sas.sasview.__build__
 __download_page__ = 'https://github.com/SasView/sasview/releases'
 __update_URL__ = 'http://www.sasview.org/latestversion.json'
@@ -34,11 +31,10 @@ __EVT_DEBUG_FILENAME__ = "debug.log"
 # About box info
 _do_aboutbox = True
 _do_acknowledge = True
-_do_release = True
 _do_tutorial = True
 _acknowledgement_preamble =\
-'''To ensure the long term support and development of this software please
-remember to:'''
+'''To ensure the long term support and development of this software please''' +\
+''' remember to:'''
 _acknowledgement_preamble_bullet1 =\
 '''Acknowledge its use in your publications as :'''
 _acknowledgement_preamble_bullet2 =\
@@ -48,20 +44,13 @@ _acknowledgement_preamble_bullet3 =\
 _acknowledgement_preamble_bullet4 =\
 '''Send us your reference for our records: developers@sasview.org'''
 _acknowledgement_publications = \
-("This work benefited from the use of the SasView application, originally"
-"developed under NSF Award DMR-0520547. SasView also contains code developed"
-"with funding from the EU Horizon 2020 programme under the SINE2020 project"
-"Grant No 654000.")
+'''This work benefited from the use of the SasView application, originally developed under NSF Award DMR-0520547. SasView also contains code developed with funding from the EU Horizon 2020 programme under the SINE2020 project Grant No 654000.'''
 _acknowledgement_citation = \
-'''M. Doucet et al. SasView Version %s, %s''' % (__version__, __DOI__)
+'''M. Doucet et al. SasView Version 5.0'''
+
 _acknowledgement =  \
-("This work was originally developed as part of the DANSE project funded by"
-"the US NSF under Award DMR-0520547,\n but is currently maintained by a"
-"collaboration between UTK, UMD, NIST, ORNL, ISIS, ESS, ILL, ANSTO, TU Delft,"
-"DLS, BAM and the scattering community.\n\n SasView also contains code"
-"developed with funding from the EU Horizon 2020 programme under the SINE2020"
-"project (Grant No 654000).\nA list of individual contributors can be found"
-"at: http://www.sasview.org/contact.html")
+'''This work was originally developed as part of the DANSE project funded by the US NSF under Award DMR-0520547,\n but is currently maintained by a collaboration between UTK, UMD, NIST, ORNL, ISIS, ESS, ILL, ANSTO, TU Delft, DLS, and the scattering community.\n\n SasView also contains code developed with funding from the EU Horizon 2020 programme under the SINE2020 project (Grant No 654000).\nA list of individual contributors can be found at: http://www.sasview.org/contact.html
+'''
 
 _homepage = "http://www.sasview.org"
 _download = __download_page__
@@ -71,7 +60,7 @@ _license = "mailto:help@sasview.org"
 
 
 icon_path = os.path.abspath(os.path.join(os.path.dirname(__file__), "images"))
-logger.info("icon path: %s" % icon_path)
+# logging.info("icon path: %s" % icon_path)
 media_path = os.path.abspath(os.path.join(os.path.dirname(__file__), "media"))
 test_path = os.path.abspath(os.path.join(os.path.dirname(__file__), "test"))
 
@@ -85,7 +74,6 @@ _ill_logo = os.path.join(icon_path, "ill_logo.png")
 _ansto_logo = os.path.join(icon_path, "ansto_logo.png")
 _tudelft_logo = os.path.join(icon_path, "tudelft_logo.png")
 _dls_logo = os.path.join(icon_path, "dls_logo.png")
-_bam_logo = os.path.join(icon_path, "bam_logo.png")
 _nsf_logo = os.path.join(icon_path, "nsf_logo.png")
 _danse_logo = os.path.join(icon_path, "danse_logo.png")
 _inst_logo = os.path.join(icon_path, "utlogo.gif")
@@ -104,8 +92,7 @@ _danse_url = "http://www.cacr.caltech.edu/projects/danse/release/index.html"
 _inst_url = "http://www.utk.edu"
 _corner_image = os.path.join(icon_path, "angles_flat.png")
 _welcome_image = os.path.join(icon_path, "SVwelcome.png")
-_copyright = ("(c) 2009 - %s, UTK, UMD, NIST, ORNL, ISIS, ESS, ILL, ANSTO,"
-              "TU Delft, DLS and BAM") % __release_date__
+_copyright = "(c) 2009 - 2019, UTK, UMD, NIST, ORNL, ISIS, ESS, ILL, ANSTO, TU Delft and DLS"
 marketplace_url = "http://marketplace.sasview.org/"
 
 #edit the list of file state your plugin can read
@@ -124,8 +111,10 @@ DATAPANEL_WIDTH = 235
 DATAPANEL_HEIGHT = 700
 SPLASH_SCREEN_PATH = os.path.join(icon_path, "SVwelcome_mini.png")
 TUTORIAL_PATH = os.path.join(media_path, "Tutorial.pdf")
-DEFAULT_STYLE = GUIFRAME.MULTIPLE_APPLICATIONS|GUIFRAME.MANAGER_ON\
-                    |GUIFRAME.CALCULATOR_ON|GUIFRAME.TOOLBAR_ON
+#DEFAULT_STYLE = GUIFRAME.MULTIPLE_APPLICATIONS|GUIFRAME.MANAGER_ON\
+#                    |GUIFRAME.CALCULATOR_ON|GUIFRAME.TOOLBAR_ON
+DEFAULT_STYLE = 64
+
 SPLASH_SCREEN_WIDTH = 512
 SPLASH_SCREEN_HEIGHT = 366
 SS_MAX_DISPLAY_TIME = 2000
@@ -156,8 +145,8 @@ DEFAULT_PERSPECTIVE = 'None'
 # Time out for updating sasview
 UPDATE_TIMEOUT = 2
 
-# Time out for updating sasview
-UPDATE_TIMEOUT = 2
+#OpenCL option
+SAS_OPENCL = None
 
 def printEVT(message):
     if __EVT_DEBUG__:
